@@ -65,9 +65,9 @@ class GitAPI:
     def get_unmerged_branch_names(self, context):
         unmerged_branches = self.command_executor.execute_immutable_command(
             context,
-            'git branch --no-color --no-merged'.split(),
+            'git branch -a --no-color --no-merged'.split(),
             True
-        )
+        ).split()
         return unmerged_branches
 
     def remove_branch(self, context, branch_name):
