@@ -4,7 +4,9 @@ import sys
 
 def setup(context):
 
-    # get any CLI switches in the context - experimental...
+    # get any CLI switches in the context:
+    # look at any parameter that starts with '--', and if the NEXT parameter doesn't
+    # start with '--', assume it's the value for this parameter
     argc = len(sys.argv)
     for i in range(argc):
         param = sys.argv[i]
@@ -32,8 +34,8 @@ def setup(context):
                 # this one started with '--', so skip it AND the following value
                 i += 2
 
-    # if there's no command set now, default it to 'help'
-    context['command'] = context.get('command', 'help')
+    # if there's no command set now, default it to 'head'
+    context['command'] = context.get('command', 'head')
 
     if context.get('no_color', False):
         Color.disable_color()
@@ -49,12 +51,34 @@ def command_handler(context):
     context['dry_run'] = context.get('dry_run', False)
 
     # show some minimal context info
-    print('current branch:  {}'.format(Color.green(context['current_branch'])))
-    print('project type:    {}'.format(Color.green(context['project_type'].get_name())))
-    print('current version: {}'.format(Color.green(context.get('current_version', 'unknown'))))
-    print('command name:    {}'.format(Color.green(context['command'])))
+    if len(context['tags_on_commit']) > 0:
+        tags = '(tags: {})'.format(Color.green(context['tags_on_commit']))
+    else:
+        tags = ''
+    print(
+        'current branch:            {} {}'.format(
+            Color.green(context['current_branch']),
+            tags
+        )
+    )
+    print(
+        'project type / version:    {} / {}'.format(
+            Color.green(context['project_type'].get_name()),
+            Color.green(context.get('current_version', 'unknown'))
+        )
+    )
+
     if context['dry_run']:
-        print('dry run:         {}'.format(Color.red_lt(context['dry_run'])))
+        dry_run = (Color.red_lt('(dry run)'))
+    else:
+        dry_run = ''
+
+    print(
+        'command name:              {} {}'.format(
+            Color.green(context['command']),
+            dry_run
+        )
+    )
 
     # look for a command object for this command...
     for value in context["commands"]:
